==> nted_0.24.1.orig.tar.gz: nted-0.24.1/midiimporter.h <==
/****************************************************************************************/
/*											*/
/* This program is free software; you can redistribute it and/or modify it under the	*/
/* terms of the GNU General Public License as published by the Free Software		*/
/* Foundation; either version 2 of the License, or (at your option) any later version.	*/
/*											*/
/* This program is distributed in the hope that it will be useful, but WITHOUT ANY	*/
/* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A	*/
/* PARTICULAR PURPOSE. See the GNU General Public License for more details.		*/
/*											*/
/* You should have received a copy of the GNU General Public License along with this	*/
/* program; (See "COPYING"). If not, If not, see <http://www.gnu.org/licenses/>.        */
/*											*/
/*--------------------------------------------------------------------------------------*/
/*											*/
/*  Copyright   Joerg Anders, TU Chemnitz, Fakultaet fuer Informatik, GERMANY           */
/*		ja@informatik.tu-chemnitz.de						*/
/*											*/
/*											*/
/****************************************************************************************/

#include <stdio.h>
#include <gtk/gtk.h>
#include "importer.h"

class NedInstrumentTable;

class NedMidiImporter : public NedImporter  {
	public:
		NedMidiImporter(bool with_triplets, bool with_single_triplets, int voice_num,
			int tempo_change_density, int volume_change_density);
		virtual ~NedMidiImporter();
		virtual bool import();
		virtual const char *getErrorString() {return m_error_string;}
	private:
		void read_header(FILE *fp);
		void readTrack(FILE *fp, int track_nr, int pass);
		unsigned long read_val_var(FILE *fp, int *len);
		int readdword(FILE *fp, int *data);
		int readword(FILE *fp, short *data);
		const char *m_error_string;
		short m_format, m_ntracks, m_division;
		unsigned long long m_current_time;
		NedInstrumentTable *m_instrument_table;
		int m_current_midi_instrument[16];
};

==> nted_1.4.17.orig.tar.gz: nted-1.4.17/midiimporter.h <==
/****************************************************************************************/
/*											*/
/* This program is free software; you can redistribute it and/or modify it under the	*/
/* terms of the GNU General Public License as published by the Free Software		*/
/* Foundation; either version 2 of the License, or (at your option) any later version.	*/
/*											*/
/* This program is distributed in the hope that it will be useful, but WITHOUT ANY	*/
/* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A	*/
/* PARTICULAR PURPOSE. See the GNU General Public License for more details.		*/
/*											*/
/* You should have received a copy of the GNU General Public License along with this	*/
/* program; (See "COPYING"). If not, If not, see <http://www.gnu.org/licenses/>.        */
/*											*/
/*--------------------------------------------------------------------------------------*/
/*											*/
/*  Copyright   Joerg Anders, TU Chemnitz, Fakultaet fuer Informatik, GERMANY           */
/*		ja@informatik.tu-chemnitz.de						*/
/*											*/
/*											*/
/****************************************************************************************/

#include <stdio.h>
#include <gtk/gtk.h>
#include "importer.h"

class NedInstrumentTable;

class NedMidiImporter : public NedImporter  {
	public:
		NedMidiImporter(bool with_triplets, bool with_single_triplets, bool with_alto_clef, int voice_num,
			int tempo_change_density, int volume_change_density, bool force_piano, bool force_one_staff);
		virtual ~NedMidiImporter();
		virtual bool import();
		virtual const char *getErrorString() {return m_error_string;}
	private:
		void read_header(FILE *fp);
		void readTrack(FILE *fp, int track_nr, int pass);
		unsigned long read_val_var(FILE *fp, int *len);
		int readdword(FILE *fp, int *data);
		int readword(FILE *fp, short *data);
		const char *m_error_string;
		short m_format, m_ntracks, m_division;
		unsigned long long m_current_time;
		NedInstrumentTable *m_instrument_table;
		int m_current_midi_instrument[16];
};
